#pragma once
#ifndef _DBICXX_CONTAINER_H
#define _DBICXX_CONTAINER_H

#include <stdarg.h>
#include <sstream>

#include "result_row.h"
#include "result_row_hash.h"
#include "field_set.h"

#endif
